// --- Automatyczny reconnect po powrocie do karty/przywróceniu internetu ---
function reconnectIfNeeded() {
    if (!socket.connected) {
        socket.connect();
    }
}

document.addEventListener("visibilitychange", function() {
    if (!document.hidden) {
        reconnectIfNeeded();
    }
});

window.addEventListener("focus", function() {
    reconnectIfNeeded();
});

window.addEventListener("online", function() {
    reconnectIfNeeded();
});

// --- Blokowanie checkboxów na czas reconnect ---
function disableCheckboxes(disable) {
    document.querySelectorAll('#items input[type="checkbox"]').forEach(cb => {
        cb.disabled = disable;
    });
}

// --- Toasty przy rozłączeniu i połączeniu ---
let firstConnect = true;

socket.on('connect', function() {
    if (!firstConnect) {
        showToast('Połączono z serwerem! 🔄', 'info');

        // Zablokuj checkboxy tymczasowo
        disableCheckboxes(true);

        if (window.LIST_ID && window.usernameForReconnect) {
            console.log('Ponownie wysyłam join_list:', window.LIST_ID, window.usernameForReconnect);
            socket.emit('join_list', { room: window.LIST_ID, username: window.usernameForReconnect });
        }
    }
    firstConnect = false;
});

socket.on('joined_confirmation', function(data) {
    console.log('Potwierdzenie joined:', data.room);
    showToast('Pokój ponownie dołączony ✅', 'info');

    // Odblokuj checkboxy
    disableCheckboxes(false);
});

socket.on('disconnect', function(reason) {
    showToast('Utracono połączenie z serwerem...', 'warning');

    // Zablokuj checkboxy
    disableCheckboxes(true);
});
